==> fr.opensagres.xdocreport.itext.extension-0.9.1-sources.jar: fr/opensagres/xdocreport/itext/extension/MasterPage.java <==
/**
 * Copyright (C) 2011 Angelo Zerr <angelo.zerr@gmail.com> and Pascal Leclercq <pascal.leclercq@gmail.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.itext.extension;

public class MasterPage {

	private final String name;
	private IMasterPageHeaderFooter header;
	private IMasterPageHeaderFooter footer;

	public MasterPage(String name) {
		this.name = name;
	}

	public IMasterPageHeaderFooter getHeader() {
		return header;
	}

	public void setHeader(IMasterPageHeaderFooter header) {
		this.header = header;
	}

	public IMasterPageHeaderFooter getFooter() {
		return footer;
	}

	public void setFooter(IMasterPageHeaderFooter footer) {
		this.footer = footer;
	}
	
	public String getName() {
		return name;
	}

}

==> fr.opensagres.xdocreport.itext.extension-1.0.4-sources.jar: fr/opensagres/xdocreport/itext/extension/MasterPage.java <==
/**
 * Copyright (C) 2011-2012 The XDocReport Team <xdocreport@googlegroups.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.itext.extension;

public class MasterPage
    implements IMasterPage
{

    private final String name;

    private IMasterPageHeaderFooter header;

    private IMasterPageHeaderFooter footer;

    public MasterPage( String name )
    {
        this.name = name;
    }

    public IMasterPageHeaderFooter getHeader()
    {
        return header;
    }

    public void setHeader( IMasterPageHeaderFooter header )
    {
        this.header = header;
    }

    public IMasterPageHeaderFooter getFooter()
    {
        return footer;
    }

    public void setFooter( IMasterPageHeaderFooter footer )
    {
        this.footer = footer;
    }

    public String getName()
    {
        return name;
    }

}
